import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CloudSqlConnectionProfile(typing_extensions.TypedDict, total=False):
    cloudSqlId: str
    privateIp: str
    publicIp: str
    settings: CloudSqlSettings

@typing.type_check_only
class CloudSqlSettings(typing_extensions.TypedDict, total=False):
    activationPolicy: typing_extensions.Literal[
        "SQL_ACTIVATION_POLICY_UNSPECIFIED", "ALWAYS", "NEVER"
    ]
    autoStorageIncrease: bool
    dataDiskSizeGb: str
    dataDiskType: typing_extensions.Literal[
        "SQL_DATA_DISK_TYPE_UNSPECIFIED", "PD_SSD", "PD_HDD"
    ]
    databaseFlags: dict[str, typing.Any]
    databaseVersion: typing_extensions.Literal[
        "SQL_DATABASE_VERSION_UNSPECIFIED", "MYSQL_5_6", "MYSQL_5_7", "MYSQL_8_0"
    ]
    ipConfig: SqlIpConfig
    rootPassword: str
    rootPasswordSet: bool
    sourceId: str
    storageAutoResizeLimit: str
    tier: str
    userLabels: dict[str, typing.Any]
    zone: str

@typing.type_check_only
class ConnectionProfile(typing_extensions.TypedDict, total=False):
    cloudsql: CloudSqlConnectionProfile
    createTime: str
    displayName: str
    error: Status
    labels: dict[str, typing.Any]
    mysql: MySqlConnectionProfile
    name: str
    provider: typing_extensions.Literal[
        "DATABASE_PROVIDER_UNSPECIFIED", "CLOUDSQL", "RDS"
    ]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "DRAFT",
        "CREATING",
        "READY",
        "UPDATING",
        "DELETING",
        "DELETED",
        "FAILED",
    ]
    updateTime: str

@typing.type_check_only
class DatabaseType(typing_extensions.TypedDict, total=False):
    engine: typing_extensions.Literal["DATABASE_ENGINE_UNSPECIFIED", "MYSQL"]
    provider: typing_extensions.Literal[
        "DATABASE_PROVIDER_UNSPECIFIED", "CLOUDSQL", "RDS"
    ]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GenerateSshScriptRequest(typing_extensions.TypedDict, total=False):
    vm: str
    vmCreationConfig: VmCreationConfig
    vmPort: int
    vmSelectionConfig: VmSelectionConfig

@typing.type_check_only
class GoogleCloudClouddmsV1beta1OperationMetadata(
    typing_extensions.TypedDict, total=False
):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class ListConnectionProfilesResponse(typing_extensions.TypedDict, total=False):
    connectionProfiles: _list[ConnectionProfile]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListMigrationJobsResponse(typing_extensions.TypedDict, total=False):
    migrationJobs: _list[MigrationJob]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class MigrationJob(typing_extensions.TypedDict, total=False):
    createTime: str
    destination: str
    destinationDatabase: DatabaseType
    displayName: str
    dumpPath: str
    duration: str
    endTime: str
    error: Status
    labels: dict[str, typing.Any]
    name: str
    phase: typing_extensions.Literal[
        "PHASE_UNSPECIFIED",
        "FULL_DUMP",
        "CDC",
        "PROMOTE_IN_PROGRESS",
        "WAITING_FOR_SOURCE_WRITES_TO_STOP",
        "PREPARING_THE_DUMP",
    ]
    reverseSshConnectivity: ReverseSshConnectivity
    source: str
    sourceDatabase: DatabaseType
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "MAINTENANCE",
        "DRAFT",
        "CREATING",
        "NOT_STARTED",
        "RUNNING",
        "FAILED",
        "COMPLETED",
        "DELETING",
        "STOPPING",
        "STOPPED",
        "DELETED",
        "UPDATING",
        "STARTING",
        "RESTARTING",
        "RESUMING",
    ]
    staticIpConnectivity: StaticIpConnectivity
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "ONE_TIME", "CONTINUOUS"]
    updateTime: str
    vpcPeeringConnectivity: VpcPeeringConnectivity

@typing.type_check_only
class MigrationJobVerificationError(typing_extensions.TypedDict, total=False):
    errorCode: typing_extensions.Literal[
        "ERROR_CODE_UNSPECIFIED",
        "CONNECTION_FAILURE",
        "AUTHENTICATION_FAILURE",
        "INVALID_CONNECTION_PROFILE_CONFIG",
        "VERSION_INCOMPATIBILITY",
        "CONNECTION_PROFILE_TYPES_INCOMPATIBILITY",
        "UNSUPPORTED_GTID_MODE",
        "UNSUPPORTED_DEFINER",
        "CANT_RESTART_RUNNING_MIGRATION",
        "TABLES_WITH_LIMITED_SUPPORT",
    ]
    errorDetailMessage: str
    errorMessage: str

@typing.type_check_only
class MySqlConnectionProfile(typing_extensions.TypedDict, total=False):
    cloudSqlId: str
    host: str
    password: str
    passwordSet: bool
    port: int
    ssl: SslConfig
    username: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PromoteMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RestartMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ResumeMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ReverseSshConnectivity(typing_extensions.TypedDict, total=False):
    vm: str
    vmIp: str
    vmPort: int
    vpc: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class SqlAclEntry(typing_extensions.TypedDict, total=False):
    expireTime: str
    label: str
    ttl: str
    value: str

@typing.type_check_only
class SqlIpConfig(typing_extensions.TypedDict, total=False):
    authorizedNetworks: _list[SqlAclEntry]
    enableIpv4: bool
    privateNetwork: str
    requireSsl: bool

@typing.type_check_only
class SshScript(typing_extensions.TypedDict, total=False):
    script: str

@typing.type_check_only
class SslConfig(typing_extensions.TypedDict, total=False):
    caCertificate: str
    clientCertificate: str
    clientKey: str
    type: typing_extensions.Literal[
        "SSL_TYPE_UNSPECIFIED", "SERVER_ONLY", "SERVER_CLIENT"
    ]

@typing.type_check_only
class StartMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class StaticIpConnectivity(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class StopMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class VerifyMigrationJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class VmCreationConfig(typing_extensions.TypedDict, total=False):
    subnet: str
    vmMachineType: str
    vmZone: str

@typing.type_check_only
class VmSelectionConfig(typing_extensions.TypedDict, total=False):
    vmZone: str

@typing.type_check_only
class VpcPeeringConnectivity(typing_extensions.TypedDict, total=False):
    vpc: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class HttpBody(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    extensions: _list[dict[str, typing.Any]]

@typing.type_check_only
class Link(typing_extensions.TypedDict, total=False):
    href: str
    hreflang: str
    media: str
    rel: str
    title: str
    type: str
    value: str

@typing.type_check_only
class Notice(typing_extensions.TypedDict, total=False):
    description: _list[str]
    links: _list[Link]
    title: str
    type: str

@typing.type_check_only
class RdapResponse(typing_extensions.TypedDict, total=False):
    description: _list[str]
    errorCode: int
    jsonResponse: HttpBody
    lang: str
    notices: _list[Notice]
    rdapConformance: _list[str]
    title: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class GamesConfigurationResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AchievementConfigurationsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, achievementId: str, **kwargs: typing.Any
        ) -> AchievementConfigurationHttpRequest: ...
        def insert(
            self,
            *,
            applicationId: str,
            body: AchievementConfiguration = ...,
            **kwargs: typing.Any
        ) -> AchievementConfigurationHttpRequest: ...
        def list(
            self,
            *,
            applicationId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> AchievementConfigurationListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: AchievementConfigurationListResponseHttpRequest,
            previous_response: AchievementConfigurationListResponse,
        ) -> AchievementConfigurationListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            achievementId: str,
            body: AchievementConfiguration = ...,
            **kwargs: typing.Any
        ) -> AchievementConfigurationHttpRequest: ...

    @typing.type_check_only
    class ImageConfigurationsResource(googleapiclient.discovery.Resource):
        def upload(
            self,
            *,
            resourceId: str,
            imageType: typing_extensions.Literal[
                "IMAGE_TYPE_UNSPECIFIED", "ACHIEVEMENT_ICON", "LEADERBOARD_ICON"
            ],
            **kwargs: typing.Any
        ) -> ImageConfigurationHttpRequest: ...

    @typing.type_check_only
    class LeaderboardConfigurationsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, leaderboardId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, leaderboardId: str, **kwargs: typing.Any
        ) -> LeaderboardConfigurationHttpRequest: ...
        def insert(
            self,
            *,
            applicationId: str,
            body: LeaderboardConfiguration = ...,
            **kwargs: typing.Any
        ) -> LeaderboardConfigurationHttpRequest: ...
        def list(
            self,
            *,
            applicationId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> LeaderboardConfigurationListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: LeaderboardConfigurationListResponseHttpRequest,
            previous_response: LeaderboardConfigurationListResponse,
        ) -> LeaderboardConfigurationListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            leaderboardId: str,
            body: LeaderboardConfiguration = ...,
            **kwargs: typing.Any
        ) -> LeaderboardConfigurationHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def achievementConfigurations(self) -> AchievementConfigurationsResource: ...
    def imageConfigurations(self) -> ImageConfigurationsResource: ...
    def leaderboardConfigurations(self) -> LeaderboardConfigurationsResource: ...

@typing.type_check_only
class AchievementConfigurationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementConfiguration: ...

@typing.type_check_only
class AchievementConfigurationListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AchievementConfigurationListResponse: ...

@typing.type_check_only
class ImageConfigurationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ImageConfiguration: ...

@typing.type_check_only
class LeaderboardConfigurationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LeaderboardConfiguration: ...

@typing.type_check_only
class LeaderboardConfigurationListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LeaderboardConfigurationListResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ScriptResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProcessesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            userProcessFilter_deploymentId: str = ...,
            userProcessFilter_endTime: str = ...,
            userProcessFilter_functionName: str = ...,
            userProcessFilter_projectName: str = ...,
            userProcessFilter_scriptId: str = ...,
            userProcessFilter_startTime: str = ...,
            userProcessFilter_statuses: typing_extensions.Literal[
                "PROCESS_STATUS_UNSPECIFIED",
                "RUNNING",
                "PAUSED",
                "COMPLETED",
                "CANCELED",
                "FAILED",
                "TIMED_OUT",
                "UNKNOWN",
                "DELAYED",
            ]
            | _list[
                typing_extensions.Literal[
                    "PROCESS_STATUS_UNSPECIFIED",
                    "RUNNING",
                    "PAUSED",
                    "COMPLETED",
                    "CANCELED",
                    "FAILED",
                    "TIMED_OUT",
                    "UNKNOWN",
                    "DELAYED",
                ]
            ] = ...,
            userProcessFilter_types: typing_extensions.Literal[
                "PROCESS_TYPE_UNSPECIFIED",
                "ADD_ON",
                "EXECUTION_API",
                "TIME_DRIVEN",
                "TRIGGER",
                "WEBAPP",
                "EDITOR",
                "SIMPLE_TRIGGER",
                "MENU",
                "BATCH_TASK",
            ]
            | _list[
                typing_extensions.Literal[
                    "PROCESS_TYPE_UNSPECIFIED",
                    "ADD_ON",
                    "EXECUTION_API",
                    "TIME_DRIVEN",
                    "TRIGGER",
                    "WEBAPP",
                    "EDITOR",
                    "SIMPLE_TRIGGER",
                    "MENU",
                    "BATCH_TASK",
                ]
            ] = ...,
            userProcessFilter_userAccessLevels: typing_extensions.Literal[
                "USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"
            ]
            | _list[
                typing_extensions.Literal[
                    "USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> ListUserProcessesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListUserProcessesResponseHttpRequest,
            previous_response: ListUserProcessesResponse,
        ) -> ListUserProcessesResponseHttpRequest | None: ...
        def listScriptProcesses(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            scriptId: str = ...,
            scriptProcessFilter_deploymentId: str = ...,
            scriptProcessFilter_endTime: str = ...,
            scriptProcessFilter_functionName: str = ...,
            scriptProcessFilter_startTime: str = ...,
            scriptProcessFilter_statuses: typing_extensions.Literal[
                "PROCESS_STATUS_UNSPECIFIED",
                "RUNNING",
                "PAUSED",
                "COMPLETED",
                "CANCELED",
                "FAILED",
                "TIMED_OUT",
                "UNKNOWN",
                "DELAYED",
            ]
            | _list[
                typing_extensions.Literal[
                    "PROCESS_STATUS_UNSPECIFIED",
                    "RUNNING",
                    "PAUSED",
                    "COMPLETED",
                    "CANCELED",
                    "FAILED",
                    "TIMED_OUT",
                    "UNKNOWN",
                    "DELAYED",
                ]
            ] = ...,
            scriptProcessFilter_types: typing_extensions.Literal[
                "PROCESS_TYPE_UNSPECIFIED",
                "ADD_ON",
                "EXECUTION_API",
                "TIME_DRIVEN",
                "TRIGGER",
                "WEBAPP",
                "EDITOR",
                "SIMPLE_TRIGGER",
                "MENU",
                "BATCH_TASK",
            ]
            | _list[
                typing_extensions.Literal[
                    "PROCESS_TYPE_UNSPECIFIED",
                    "ADD_ON",
                    "EXECUTION_API",
                    "TIME_DRIVEN",
                    "TRIGGER",
                    "WEBAPP",
                    "EDITOR",
                    "SIMPLE_TRIGGER",
                    "MENU",
                    "BATCH_TASK",
                ]
            ] = ...,
            scriptProcessFilter_userAccessLevels: typing_extensions.Literal[
                "USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"
            ]
            | _list[
                typing_extensions.Literal[
                    "USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> ListScriptProcessesResponseHttpRequest: ...
        def listScriptProcesses_next(
            self,
            previous_request: ListScriptProcessesResponseHttpRequest,
            previous_response: ListScriptProcessesResponse,
        ) -> ListScriptProcessesResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeploymentsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                scriptId: str,
                body: DeploymentConfig = ...,
                **kwargs: typing.Any
            ) -> DeploymentHttpRequest: ...
            def delete(
                self, *, scriptId: str, deploymentId: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, scriptId: str, deploymentId: str, **kwargs: typing.Any
            ) -> DeploymentHttpRequest: ...
            def list(
                self,
                *,
                scriptId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDeploymentsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDeploymentsResponseHttpRequest,
                previous_response: ListDeploymentsResponse,
            ) -> ListDeploymentsResponseHttpRequest | None: ...
            def update(
                self,
                *,
                scriptId: str,
                deploymentId: str,
                body: UpdateDeploymentRequest = ...,
                **kwargs: typing.Any
            ) -> DeploymentHttpRequest: ...

        @typing.type_check_only
        class VersionsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, scriptId: str, body: Version = ..., **kwargs: typing.Any
            ) -> VersionHttpRequest: ...
            def get(
                self, *, scriptId: str, versionNumber: int, **kwargs: typing.Any
            ) -> VersionHttpRequest: ...
            def list(
                self,
                *,
                scriptId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListVersionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListVersionsResponseHttpRequest,
                previous_response: ListVersionsResponse,
            ) -> ListVersionsResponseHttpRequest | None: ...

        def create(
            self, *, body: CreateProjectRequest = ..., **kwargs: typing.Any
        ) -> ProjectHttpRequest: ...
        def get(self, *, scriptId: str, **kwargs: typing.Any) -> ProjectHttpRequest: ...
        def getContent(
            self, *, scriptId: str, versionNumber: int = ..., **kwargs: typing.Any
        ) -> ContentHttpRequest: ...
        def getMetrics(
            self,
            *,
            scriptId: str,
            metricsFilter_deploymentId: str = ...,
            metricsGranularity: typing_extensions.Literal[
                "UNSPECIFIED_GRANULARITY", "WEEKLY", "DAILY"
            ] = ...,
            **kwargs: typing.Any
        ) -> MetricsHttpRequest: ...
        def updateContent(
            self, *, scriptId: str, body: Content = ..., **kwargs: typing.Any
        ) -> ContentHttpRequest: ...
        def deployments(self) -> DeploymentsResource: ...
        def versions(self) -> VersionsResource: ...

    @typing.type_check_only
    class ScriptsResource(googleapiclient.discovery.Resource):
        def run(
            self, *, scriptId: str, body: ExecutionRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def processes(self) -> ProcessesResource: ...
    def projects(self) -> ProjectsResource: ...
    def scripts(self) -> ScriptsResource: ...

@typing.type_check_only
class ContentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Content: ...

@typing.type_check_only
class DeploymentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Deployment: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListDeploymentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDeploymentsResponse: ...

@typing.type_check_only
class ListScriptProcessesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListScriptProcessesResponse: ...

@typing.type_check_only
class ListUserProcessesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUserProcessesResponse: ...

@typing.type_check_only
class ListVersionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListVersionsResponse: ...

@typing.type_check_only
class MetricsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Metrics: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ProjectHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Project: ...

@typing.type_check_only
class VersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Version: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AcceptProposalRequest(typing_extensions.TypedDict, total=False):
    proposalRevision: str

@typing.type_check_only
class ActivateClientRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ActivateClientUserRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class AdSize(typing_extensions.TypedDict, total=False):
    height: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "PIXEL", "INTERSTITIAL", "NATIVE", "FLUID"
    ]
    width: str

@typing.type_check_only
class AddCreativeRequest(typing_extensions.TypedDict, total=False):
    creative: str

@typing.type_check_only
class AddNoteRequest(typing_extensions.TypedDict, total=False):
    note: Note

@typing.type_check_only
class AuctionPackage(typing_extensions.TypedDict, total=False):
    createTime: str
    creator: str
    description: str
    displayName: str
    name: str
    subscribedClients: _list[str]
    updateTime: str

@typing.type_check_only
class BatchUpdateDealsRequest(typing_extensions.TypedDict, total=False):
    requests: _list[UpdateDealRequest]

@typing.type_check_only
class BatchUpdateDealsResponse(typing_extensions.TypedDict, total=False):
    deals: _list[Deal]

@typing.type_check_only
class CancelNegotiationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Client(typing_extensions.TypedDict, total=False):
    displayName: str
    name: str
    partnerClientId: str
    role: typing_extensions.Literal[
        "CLIENT_ROLE_UNSPECIFIED",
        "CLIENT_DEAL_VIEWER",
        "CLIENT_DEAL_NEGOTIATOR",
        "CLIENT_DEAL_APPROVER",
    ]
    sellerVisible: bool
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "INACTIVE"]

@typing.type_check_only
class ClientUser(typing_extensions.TypedDict, total=False):
    email: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "INVITED", "ACTIVE", "INACTIVE"
    ]

@typing.type_check_only
class Contact(typing_extensions.TypedDict, total=False):
    displayName: str
    email: str

@typing.type_check_only
class CreativeRequirements(typing_extensions.TypedDict, total=False):
    creativeFormat: typing_extensions.Literal[
        "CREATIVE_FORMAT_UNSPECIFIED", "DISPLAY", "VIDEO"
    ]
    creativePreApprovalPolicy: typing_extensions.Literal[
        "CREATIVE_PRE_APPROVAL_POLICY_UNSPECIFIED",
        "SELLER_PRE_APPROVAL_REQUIRED",
        "SELLER_PRE_APPROVAL_NOT_REQUIRED",
    ]
    creativeSafeFrameCompatibility: typing_extensions.Literal[
        "CREATIVE_SAFE_FRAME_COMPATIBILITY_UNSPECIFIED", "COMPATIBLE", "INCOMPATIBLE"
    ]
    maxAdDurationMs: str
    programmaticCreativeSource: typing_extensions.Literal[
        "PROGRAMMATIC_CREATIVE_SOURCE_UNSPECIFIED", "ADVERTISER", "PUBLISHER"
    ]
    skippableAdType: typing_extensions.Literal[
        "SKIPPABLE_AD_TYPE_UNSPECIFIED",
        "SKIPPABLE",
        "INSTREAM_SELECT",
        "NOT_SKIPPABLE",
        "ANY",
    ]

@typing.type_check_only
class CriteriaTargeting(typing_extensions.TypedDict, total=False):
    excludedCriteriaIds: _list[str]
    targetedCriteriaIds: _list[str]

@typing.type_check_only
class DayPart(typing_extensions.TypedDict, total=False):
    dayOfWeek: typing_extensions.Literal[
        "DAY_OF_WEEK_UNSPECIFIED",
        "MONDAY",
        "TUESDAY",
        "WEDNESDAY",
        "THURSDAY",
        "FRIDAY",
        "SATURDAY",
        "SUNDAY",
    ]
    endTime: TimeOfDay
    startTime: TimeOfDay

@typing.type_check_only
class DayPartTargeting(typing_extensions.TypedDict, total=False):
    dayParts: _list[DayPart]
    timeZoneType: typing_extensions.Literal[
        "TIME_ZONE_TYPE_UNSPECIFIED", "SELLER", "USER"
    ]

@typing.type_check_only
class DeactivateClientRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DeactivateClientUserRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Deal(typing_extensions.TypedDict, total=False):
    billedBuyer: str
    buyer: str
    client: str
    createTime: str
    creativeRequirements: CreativeRequirements
    dealType: typing_extensions.Literal[
        "DEAL_TYPE_UNSPECIFIED",
        "PREFERRED_DEAL",
        "PRIVATE_AUCTION",
        "PROGRAMMATIC_GUARANTEED",
    ]
    deliveryControl: DeliveryControl
    description: str
    displayName: str
    estimatedGrossSpend: Money
    flightEndTime: str
    flightStartTime: str
    name: str
    preferredDealTerms: PreferredDealTerms
    privateAuctionTerms: PrivateAuctionTerms
    programmaticGuaranteedTerms: ProgrammaticGuaranteedTerms
    proposalRevision: str
    publisherProfile: str
    sellerTimeZone: TimeZone
    targeting: MarketplaceTargeting
    updateTime: str

@typing.type_check_only
class DealPausingInfo(typing_extensions.TypedDict, total=False):
    pauseReason: str
    pauseRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    pausingConsented: bool

@typing.type_check_only
class DeliveryControl(typing_extensions.TypedDict, total=False):
    companionDeliveryType: typing_extensions.Literal[
        "COMPANION_DELIVERY_TYPE_UNSPECIFIED",
        "DELIVERY_OPTIONAL",
        "DELIVERY_AT_LEAST_ONE",
        "DELIVERY_ALL",
    ]
    creativeRotationType: typing_extensions.Literal[
        "CREATIVE_ROTATION_TYPE_UNSPECIFIED",
        "ROTATION_EVEN",
        "ROTATION_OPTIMIZED",
        "ROTATION_MANUAL",
        "ROTATION_SEQUENTIAL",
    ]
    deliveryRateType: typing_extensions.Literal[
        "DELIVERY_RATE_TYPE_UNSPECIFIED",
        "EVENLY",
        "FRONT_LOADED",
        "AS_FAST_AS_POSSIBLE",
    ]
    frequencyCap: _list[FrequencyCap]
    roadblockingType: typing_extensions.Literal[
        "ROADBLOCKING_TYPE_UNSPECIFIED",
        "ONLY_ONE",
        "ONE_OR_MORE",
        "AS_MANY_AS_POSSIBLE",
        "ALL_ROADBLOCK",
        "CREATIVE_SET",
    ]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FinalizedDeal(typing_extensions.TypedDict, total=False):
    deal: Deal
    dealPausingInfo: DealPausingInfo
    dealServingStatus: typing_extensions.Literal[
        "DEAL_SERVING_STATUS_UNSPECIFIED",
        "ACTIVE",
        "ENDED",
        "PAUSED_BY_BUYER",
        "PAUSED_BY_SELLER",
    ]
    name: str
    readyToServe: bool
    rtbMetrics: RtbMetrics

@typing.type_check_only
class FirstPartyMobileApplicationTargeting(typing_extensions.TypedDict, total=False):
    excludedAppIds: _list[str]
    targetedAppIds: _list[str]

@typing.type_check_only
class FrequencyCap(typing_extensions.TypedDict, total=False):
    maxImpressions: int
    timeUnitType: typing_extensions.Literal[
        "TIME_UNIT_TYPE_UNSPECIFIED",
        "MINUTE",
        "HOUR",
        "DAY",
        "WEEK",
        "MONTH",
        "LIFETIME",
        "POD",
        "STREAM",
    ]
    timeUnitsCount: int

@typing.type_check_only
class InventorySizeTargeting(typing_extensions.TypedDict, total=False):
    excludedInventorySizes: _list[AdSize]
    targetedInventorySizes: _list[AdSize]

@typing.type_check_only
class InventoryTypeTargeting(typing_extensions.TypedDict, total=False):
    inventoryTypes: _list[str]

@typing.type_check_only
class ListAuctionPackagesResponse(typing_extensions.TypedDict, total=False):
    auctionPackages: _list[AuctionPackage]
    nextPageToken: str

@typing.type_check_only
class ListClientUsersResponse(typing_extensions.TypedDict, total=False):
    clientUsers: _list[ClientUser]
    nextPageToken: str

@typing.type_check_only
class ListClientsResponse(typing_extensions.TypedDict, total=False):
    clients: _list[Client]
    nextPageToken: str

@typing.type_check_only
class ListDealsResponse(typing_extensions.TypedDict, total=False):
    deals: _list[Deal]
    nextPageToken: str

@typing.type_check_only
class ListFinalizedDealsResponse(typing_extensions.TypedDict, total=False):
    finalizedDeals: _list[FinalizedDeal]
    nextPageToken: str

@typing.type_check_only
class ListProposalsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    proposals: _list[Proposal]

@typing.type_check_only
class ListPublisherProfilesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    publisherProfiles: _list[PublisherProfile]

@typing.type_check_only
class MarketplaceTargeting(typing_extensions.TypedDict, total=False):
    daypartTargeting: DayPartTargeting
    geoTargeting: CriteriaTargeting
    inventorySizeTargeting: InventorySizeTargeting
    inventoryTypeTargeting: InventoryTypeTargeting
    placementTargeting: PlacementTargeting
    technologyTargeting: TechnologyTargeting
    userListTargeting: CriteriaTargeting
    videoTargeting: VideoTargeting

@typing.type_check_only
class MobileApplicationTargeting(typing_extensions.TypedDict, total=False):
    firstPartyTargeting: FirstPartyMobileApplicationTargeting

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class Note(typing_extensions.TypedDict, total=False):
    createTime: str
    creatorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    note: str

@typing.type_check_only
class OperatingSystemTargeting(typing_extensions.TypedDict, total=False):
    operatingSystemCriteria: CriteriaTargeting
    operatingSystemVersionCriteria: CriteriaTargeting

@typing.type_check_only
class PauseFinalizedDealRequest(typing_extensions.TypedDict, total=False):
    reason: str

@typing.type_check_only
class PlacementTargeting(typing_extensions.TypedDict, total=False):
    mobileApplicationTargeting: MobileApplicationTargeting
    uriTargeting: UriTargeting

@typing.type_check_only
class PreferredDealTerms(typing_extensions.TypedDict, total=False):
    fixedPrice: Price

@typing.type_check_only
class Price(typing_extensions.TypedDict, total=False):
    amount: Money
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "CPM", "CPD"]

@typing.type_check_only
class PrivateAuctionTerms(typing_extensions.TypedDict, total=False):
    floorPrice: Price
    openAuctionAllowed: bool

@typing.type_check_only
class PrivateData(typing_extensions.TypedDict, total=False):
    referenceId: str

@typing.type_check_only
class ProgrammaticGuaranteedTerms(typing_extensions.TypedDict, total=False):
    fixedPrice: Price
    guaranteedLooks: str
    impressionCap: str
    minimumDailyLooks: str
    percentShareOfVoice: str
    reservationType: typing_extensions.Literal[
        "RESERVATION_TYPE_UNSPECIFIED", "STANDARD", "SPONSORSHIP"
    ]

@typing.type_check_only
class Proposal(typing_extensions.TypedDict, total=False):
    billedBuyer: str
    buyer: str
    buyerContacts: _list[Contact]
    buyerPrivateData: PrivateData
    client: str
    dealType: typing_extensions.Literal[
        "DEAL_TYPE_UNSPECIFIED",
        "PREFERRED_DEAL",
        "PRIVATE_AUCTION",
        "PROGRAMMATIC_GUARANTEED",
    ]
    displayName: str
    isRenegotiating: bool
    lastUpdaterOrCommentorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    name: str
    notes: _list[Note]
    originatorRole: typing_extensions.Literal[
        "BUYER_SELLER_ROLE_UNSPECIFIED", "BUYER", "SELLER"
    ]
    pausingConsented: bool
    proposalRevision: str
    publisherProfile: str
    sellerContacts: _list[Contact]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "BUYER_REVIEW_REQUESTED",
        "SELLER_REVIEW_REQUESTED",
        "BUYER_ACCEPTANCE_REQUESTED",
        "FINALIZED",
        "TERMINATED",
    ]
    termsAndConditions: str
    updateTime: str

@typing.type_check_only
class PublisherProfile(typing_extensions.TypedDict, total=False):
    audienceDescription: str
    directDealsContact: str
    displayName: str
    domains: _list[str]
    isParent: bool
    logoUrl: str
    mediaKitUrl: str
    mobileApps: _list[PublisherProfileMobileApplication]
    name: str
    overview: str
    pitchStatement: str
    programmaticDealsContact: str
    publisherCode: str
    samplePageUrl: str
    topHeadlines: _list[str]

@typing.type_check_only
class PublisherProfileMobileApplication(typing_extensions.TypedDict, total=False):
    appStore: typing_extensions.Literal[
        "APP_STORE_TYPE_UNSPECIFIED",
        "APPLE_ITUNES",
        "GOOGLE_PLAY",
        "ROKU",
        "AMAZON_FIRE_TV",
        "PLAYSTATION",
        "XBOX",
        "SAMSUNG_TV",
        "AMAZON",
        "OPPO",
        "SAMSUNG",
        "VIVO",
        "XIAOMI",
    ]
    externalAppId: str
    name: str

@typing.type_check_only
class ResumeFinalizedDealRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RtbMetrics(typing_extensions.TypedDict, total=False):
    adImpressions7Days: str
    bidRate7Days: float
    bidRequests7Days: str
    bids7Days: str
    filteredBidRate7Days: float
    mustBidRateCurrentMonth: float

@typing.type_check_only
class SendRfpRequest(typing_extensions.TypedDict, total=False):
    buyerContacts: _list[Contact]
    client: str
    displayName: str
    estimatedGrossSpend: Money
    flightEndTime: str
    flightStartTime: str
    geoTargeting: CriteriaTargeting
    inventorySizeTargeting: InventorySizeTargeting
    note: str
    preferredDealTerms: PreferredDealTerms
    programmaticGuaranteedTerms: ProgrammaticGuaranteedTerms
    publisherProfile: str

@typing.type_check_only
class SetReadyToServeRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SubscribeAuctionPackageRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SubscribeClientsRequest(typing_extensions.TypedDict, total=False):
    clients: _list[str]

@typing.type_check_only
class TechnologyTargeting(typing_extensions.TypedDict, total=False):
    deviceCapabilityTargeting: CriteriaTargeting
    deviceCategoryTargeting: CriteriaTargeting
    operatingSystemTargeting: OperatingSystemTargeting

@typing.type_check_only
class TimeOfDay(typing_extensions.TypedDict, total=False):
    hours: int
    minutes: int
    nanos: int
    seconds: int

@typing.type_check_only
class TimeZone(typing_extensions.TypedDict, total=False):
    id: str
    version: str

@typing.type_check_only
class UnsubscribeAuctionPackageRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UnsubscribeClientsRequest(typing_extensions.TypedDict, total=False):
    clients: _list[str]

@typing.type_check_only
class UpdateDealRequest(typing_extensions.TypedDict, total=False):
    deal: Deal
    updateMask: str

@typing.type_check_only
class UriTargeting(typing_extensions.TypedDict, total=False):
    excludedUris: _list[str]
    targetedUris: _list[str]

@typing.type_check_only
class VideoTargeting(typing_extensions.TypedDict, total=False):
    excludedPositionTypes: _list[str]
    targetedPositionTypes: _list[str]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudIAPResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class BrandsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class IdentityAwareProxyClientsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: IdentityAwareProxyClient = ...,
                    **kwargs: typing.Any
                ) -> IdentityAwareProxyClientHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> IdentityAwareProxyClientHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListIdentityAwareProxyClientsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListIdentityAwareProxyClientsResponseHttpRequest,
                    previous_response: ListIdentityAwareProxyClientsResponse,
                ) -> ListIdentityAwareProxyClientsResponseHttpRequest | None: ...
                def resetSecret(
                    self,
                    *,
                    name: str,
                    body: ResetIdentityAwareProxyClientSecretRequest = ...,
                    **kwargs: typing.Any
                ) -> IdentityAwareProxyClientHttpRequest: ...

            def create(
                self, *, parent: str, body: Brand = ..., **kwargs: typing.Any
            ) -> BrandHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> BrandHttpRequest: ...
            def list(
                self, *, parent: str, **kwargs: typing.Any
            ) -> ListBrandsResponseHttpRequest: ...
            def identityAwareProxyClients(
                self,
            ) -> IdentityAwareProxyClientsResource: ...

        @typing.type_check_only
        class Iap_tunnelResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class LocationsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class DestGroupsResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: TunnelDestGroup = ...,
                        tunnelDestGroupId: str = ...,
                        **kwargs: typing.Any
                    ) -> TunnelDestGroupHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> TunnelDestGroupHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListTunnelDestGroupsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListTunnelDestGroupsResponseHttpRequest,
                        previous_response: ListTunnelDestGroupsResponse,
                    ) -> ListTunnelDestGroupsResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: TunnelDestGroup = ...,
                        updateMask: str = ...,
                        **kwargs: typing.Any
                    ) -> TunnelDestGroupHttpRequest: ...

                def destGroups(self) -> DestGroupsResource: ...

            def locations(self) -> LocationsResource: ...

        def brands(self) -> BrandsResource: ...
        def iap_tunnel(self) -> Iap_tunnelResource: ...

    @typing.type_check_only
    class V1Resource(googleapiclient.discovery.Resource):
        def getIamPolicy(
            self,
            *,
            resource: str,
            body: GetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def getIapSettings(
            self, *, name: str, **kwargs: typing.Any
        ) -> IapSettingsHttpRequest: ...
        def setIamPolicy(
            self,
            *,
            resource: str,
            body: SetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def testIamPermissions(
            self,
            *,
            resource: str,
            body: TestIamPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> TestIamPermissionsResponseHttpRequest: ...
        def updateIapSettings(
            self,
            *,
            name: str,
            body: IapSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> IapSettingsHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...
    def v1(self) -> V1Resource: ...

@typing.type_check_only
class BrandHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Brand: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class IapSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IapSettings: ...

@typing.type_check_only
class IdentityAwareProxyClientHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> IdentityAwareProxyClient: ...

@typing.type_check_only
class ListBrandsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBrandsResponse: ...

@typing.type_check_only
class ListIdentityAwareProxyClientsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListIdentityAwareProxyClientsResponse: ...

@typing.type_check_only
class ListTunnelDestGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTunnelDestGroupsResponse: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class TunnelDestGroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TunnelDestGroup: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudVideointelligenceV1_AnnotateVideoProgress(
    typing_extensions.TypedDict, total=False
):
    annotationProgress: _list[GoogleCloudVideointelligenceV1_VideoAnnotationProgress]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_AnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: _list[GoogleCloudVideointelligenceV1_VideoAnnotationResults]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_DetectedAttribute(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    value: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_DetectedLandmark(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    point: GoogleCloudVideointelligenceV1_NormalizedVertex

@typing.type_check_only
class GoogleCloudVideointelligenceV1_Entity(typing_extensions.TypedDict, total=False):
    description: str
    entityId: str
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_ExplicitContentAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1_ExplicitContentFrame]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_ExplicitContentFrame(
    typing_extensions.TypedDict, total=False
):
    pornographyLikelihood: typing_extensions.Literal[
        "LIKELIHOOD_UNSPECIFIED",
        "VERY_UNLIKELY",
        "UNLIKELY",
        "POSSIBLE",
        "LIKELY",
        "VERY_LIKELY",
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_FaceAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1_FaceFrame]
    segments: _list[GoogleCloudVideointelligenceV1_FaceSegment]
    thumbnail: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_FaceDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    tracks: _list[GoogleCloudVideointelligenceV1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_FaceFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBoxes: _list[GoogleCloudVideointelligenceV1_NormalizedBoundingBox]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_FaceSegment(
    typing_extensions.TypedDict, total=False
):
    segment: GoogleCloudVideointelligenceV1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1_LabelAnnotation(
    typing_extensions.TypedDict, total=False
):
    categoryEntities: _list[GoogleCloudVideointelligenceV1_Entity]
    entity: GoogleCloudVideointelligenceV1_Entity
    frames: _list[GoogleCloudVideointelligenceV1_LabelFrame]
    segments: _list[GoogleCloudVideointelligenceV1_LabelSegment]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_LabelFrame(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_LabelSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    segment: GoogleCloudVideointelligenceV1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1_LogoRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    entity: GoogleCloudVideointelligenceV1_Entity
    segments: _list[GoogleCloudVideointelligenceV1_VideoSegment]
    tracks: _list[GoogleCloudVideointelligenceV1_Track]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_NormalizedBoundingBox(
    typing_extensions.TypedDict, total=False
):
    bottom: float
    left: float
    right: float
    top: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1_NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudVideointelligenceV1_NormalizedVertex]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1_ObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    entity: GoogleCloudVideointelligenceV1_Entity
    frames: _list[GoogleCloudVideointelligenceV1_ObjectTrackingFrame]
    segment: GoogleCloudVideointelligenceV1_VideoSegment
    trackId: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBox: GoogleCloudVideointelligenceV1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_PersonDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    tracks: _list[GoogleCloudVideointelligenceV1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_SpeechRecognitionAlternative(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    transcript: str
    words: _list[GoogleCloudVideointelligenceV1_WordInfo]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_SpeechTranscription(
    typing_extensions.TypedDict, total=False
):
    alternatives: _list[GoogleCloudVideointelligenceV1_SpeechRecognitionAlternative]
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_TextAnnotation(
    typing_extensions.TypedDict, total=False
):
    segments: _list[GoogleCloudVideointelligenceV1_TextSegment]
    text: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_TextFrame(
    typing_extensions.TypedDict, total=False
):
    rotatedBoundingBox: GoogleCloudVideointelligenceV1_NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_TextSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    frames: _list[GoogleCloudVideointelligenceV1_TextFrame]
    segment: GoogleCloudVideointelligenceV1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1_TimestampedObject(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1_DetectedAttribute]
    landmarks: _list[GoogleCloudVideointelligenceV1_DetectedLandmark]
    normalizedBoundingBox: GoogleCloudVideointelligenceV1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_Track(typing_extensions.TypedDict, total=False):
    attributes: _list[GoogleCloudVideointelligenceV1_DetectedAttribute]
    confidence: float
    segment: GoogleCloudVideointelligenceV1_VideoSegment
    timestampedObjects: _list[GoogleCloudVideointelligenceV1_TimestampedObject]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_VideoAnnotationProgress(
    typing_extensions.TypedDict, total=False
):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "LABEL_DETECTION",
        "SHOT_CHANGE_DETECTION",
        "EXPLICIT_CONTENT_DETECTION",
        "FACE_DETECTION",
        "SPEECH_TRANSCRIPTION",
        "TEXT_DETECTION",
        "OBJECT_TRACKING",
        "LOGO_RECOGNITION",
        "PERSON_DETECTION",
    ]
    inputUri: str
    progressPercent: int
    segment: GoogleCloudVideointelligenceV1_VideoSegment
    startTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_VideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    error: GoogleRpc_Status
    explicitAnnotation: GoogleCloudVideointelligenceV1_ExplicitContentAnnotation
    faceAnnotations: _list[GoogleCloudVideointelligenceV1_FaceAnnotation]
    faceDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1_FaceDetectionAnnotation
    ]
    frameLabelAnnotations: _list[GoogleCloudVideointelligenceV1_LabelAnnotation]
    inputUri: str
    logoRecognitionAnnotations: _list[
        GoogleCloudVideointelligenceV1_LogoRecognitionAnnotation
    ]
    objectAnnotations: _list[GoogleCloudVideointelligenceV1_ObjectTrackingAnnotation]
    personDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1_PersonDetectionAnnotation
    ]
    segment: GoogleCloudVideointelligenceV1_VideoSegment
    segmentLabelAnnotations: _list[GoogleCloudVideointelligenceV1_LabelAnnotation]
    segmentPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1_LabelAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1_VideoSegment]
    shotLabelAnnotations: _list[GoogleCloudVideointelligenceV1_LabelAnnotation]
    shotPresenceLabelAnnotations: _list[GoogleCloudVideointelligenceV1_LabelAnnotation]
    speechTranscriptions: _list[GoogleCloudVideointelligenceV1_SpeechTranscription]
    textAnnotations: _list[GoogleCloudVideointelligenceV1_TextAnnotation]

@typing.type_check_only
class GoogleCloudVideointelligenceV1_VideoSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1_WordInfo(typing_extensions.TypedDict, total=False):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_AnnotateVideoProgress(
    typing_extensions.TypedDict, total=False
):
    annotationProgress: _list[
        GoogleCloudVideointelligenceV1beta2_VideoAnnotationProgress
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_AnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: _list[GoogleCloudVideointelligenceV1beta2_VideoAnnotationResults]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_DetectedAttribute(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    value: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_DetectedLandmark(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    point: GoogleCloudVideointelligenceV1beta2_NormalizedVertex

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_Entity(
    typing_extensions.TypedDict, total=False
):
    description: str
    entityId: str
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_ExplicitContentAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1beta2_ExplicitContentFrame]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_ExplicitContentFrame(
    typing_extensions.TypedDict, total=False
):
    pornographyLikelihood: typing_extensions.Literal[
        "LIKELIHOOD_UNSPECIFIED",
        "VERY_UNLIKELY",
        "UNLIKELY",
        "POSSIBLE",
        "LIKELY",
        "VERY_LIKELY",
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_FaceAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1beta2_FaceFrame]
    segments: _list[GoogleCloudVideointelligenceV1beta2_FaceSegment]
    thumbnail: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_FaceDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    tracks: _list[GoogleCloudVideointelligenceV1beta2_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_FaceFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBoxes: _list[
        GoogleCloudVideointelligenceV1beta2_NormalizedBoundingBox
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_FaceSegment(
    typing_extensions.TypedDict, total=False
):
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_LabelAnnotation(
    typing_extensions.TypedDict, total=False
):
    categoryEntities: _list[GoogleCloudVideointelligenceV1beta2_Entity]
    entity: GoogleCloudVideointelligenceV1beta2_Entity
    frames: _list[GoogleCloudVideointelligenceV1beta2_LabelFrame]
    segments: _list[GoogleCloudVideointelligenceV1beta2_LabelSegment]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_LabelFrame(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_LabelSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_LogoRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    entity: GoogleCloudVideointelligenceV1beta2_Entity
    segments: _list[GoogleCloudVideointelligenceV1beta2_VideoSegment]
    tracks: _list[GoogleCloudVideointelligenceV1beta2_Track]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_NormalizedBoundingBox(
    typing_extensions.TypedDict, total=False
):
    bottom: float
    left: float
    right: float
    top: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudVideointelligenceV1beta2_NormalizedVertex]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_ObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    entity: GoogleCloudVideointelligenceV1beta2_Entity
    frames: _list[GoogleCloudVideointelligenceV1beta2_ObjectTrackingFrame]
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment
    trackId: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBox: GoogleCloudVideointelligenceV1beta2_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_PersonDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    tracks: _list[GoogleCloudVideointelligenceV1beta2_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_SpeechRecognitionAlternative(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    transcript: str
    words: _list[GoogleCloudVideointelligenceV1beta2_WordInfo]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_SpeechTranscription(
    typing_extensions.TypedDict, total=False
):
    alternatives: _list[
        GoogleCloudVideointelligenceV1beta2_SpeechRecognitionAlternative
    ]
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_TextAnnotation(
    typing_extensions.TypedDict, total=False
):
    segments: _list[GoogleCloudVideointelligenceV1beta2_TextSegment]
    text: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_TextFrame(
    typing_extensions.TypedDict, total=False
):
    rotatedBoundingBox: GoogleCloudVideointelligenceV1beta2_NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_TextSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    frames: _list[GoogleCloudVideointelligenceV1beta2_TextFrame]
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_TimestampedObject(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1beta2_DetectedAttribute]
    landmarks: _list[GoogleCloudVideointelligenceV1beta2_DetectedLandmark]
    normalizedBoundingBox: GoogleCloudVideointelligenceV1beta2_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_Track(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1beta2_DetectedAttribute]
    confidence: float
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment
    timestampedObjects: _list[GoogleCloudVideointelligenceV1beta2_TimestampedObject]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_VideoAnnotationProgress(
    typing_extensions.TypedDict, total=False
):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "LABEL_DETECTION",
        "SHOT_CHANGE_DETECTION",
        "EXPLICIT_CONTENT_DETECTION",
        "FACE_DETECTION",
        "SPEECH_TRANSCRIPTION",
        "TEXT_DETECTION",
        "OBJECT_TRACKING",
        "LOGO_RECOGNITION",
        "PERSON_DETECTION",
    ]
    inputUri: str
    progressPercent: int
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment
    startTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_VideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    error: GoogleRpc_Status
    explicitAnnotation: GoogleCloudVideointelligenceV1beta2_ExplicitContentAnnotation
    faceAnnotations: _list[GoogleCloudVideointelligenceV1beta2_FaceAnnotation]
    faceDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_FaceDetectionAnnotation
    ]
    frameLabelAnnotations: _list[GoogleCloudVideointelligenceV1beta2_LabelAnnotation]
    inputUri: str
    logoRecognitionAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_LogoRecognitionAnnotation
    ]
    objectAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_ObjectTrackingAnnotation
    ]
    personDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_PersonDetectionAnnotation
    ]
    segment: GoogleCloudVideointelligenceV1beta2_VideoSegment
    segmentLabelAnnotations: _list[GoogleCloudVideointelligenceV1beta2_LabelAnnotation]
    segmentPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_LabelAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1beta2_VideoSegment]
    shotLabelAnnotations: _list[GoogleCloudVideointelligenceV1beta2_LabelAnnotation]
    shotPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1beta2_LabelAnnotation
    ]
    speechTranscriptions: _list[GoogleCloudVideointelligenceV1beta2_SpeechTranscription]
    textAnnotations: _list[GoogleCloudVideointelligenceV1beta2_TextAnnotation]

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_VideoSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1beta2_WordInfo(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_AnnotateVideoProgress(
    typing_extensions.TypedDict, total=False
):
    annotationProgress: _list[
        GoogleCloudVideointelligenceV1p1beta1_VideoAnnotationProgress
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_AnnotateVideoRequest(
    typing_extensions.TypedDict, total=False
):
    features: _list[str]
    inputContent: str
    inputUri: str
    locationId: str
    outputUri: str
    videoContext: GoogleCloudVideointelligenceV1p1beta1_VideoContext

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_AnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: _list[
        GoogleCloudVideointelligenceV1p1beta1_VideoAnnotationResults
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_DetectedAttribute(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    value: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_DetectedLandmark(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    point: GoogleCloudVideointelligenceV1p1beta1_NormalizedVertex

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_Entity(
    typing_extensions.TypedDict, total=False
):
    description: str
    entityId: str
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ExplicitContentAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p1beta1_ExplicitContentFrame]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ExplicitContentDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    model: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ExplicitContentFrame(
    typing_extensions.TypedDict, total=False
):
    pornographyLikelihood: typing_extensions.Literal[
        "LIKELIHOOD_UNSPECIFIED",
        "VERY_UNLIKELY",
        "UNLIKELY",
        "POSSIBLE",
        "LIKELY",
        "VERY_LIKELY",
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_FaceAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p1beta1_FaceFrame]
    segments: _list[GoogleCloudVideointelligenceV1p1beta1_FaceSegment]
    thumbnail: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_FaceDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    tracks: _list[GoogleCloudVideointelligenceV1p1beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_FaceDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    includeAttributes: bool
    includeBoundingBoxes: bool
    model: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_FaceFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBoxes: _list[
        GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingBox
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_FaceSegment(
    typing_extensions.TypedDict, total=False
):
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation(
    typing_extensions.TypedDict, total=False
):
    categoryEntities: _list[GoogleCloudVideointelligenceV1p1beta1_Entity]
    entity: GoogleCloudVideointelligenceV1p1beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p1beta1_LabelFrame]
    segments: _list[GoogleCloudVideointelligenceV1p1beta1_LabelSegment]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_LabelDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    frameConfidenceThreshold: float
    labelDetectionMode: typing_extensions.Literal[
        "LABEL_DETECTION_MODE_UNSPECIFIED",
        "SHOT_MODE",
        "FRAME_MODE",
        "SHOT_AND_FRAME_MODE",
    ]
    model: str
    stationaryCamera: bool
    videoConfidenceThreshold: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_LabelFrame(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_LabelSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_LogoRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    entity: GoogleCloudVideointelligenceV1p1beta1_Entity
    segments: _list[GoogleCloudVideointelligenceV1p1beta1_VideoSegment]
    tracks: _list[GoogleCloudVideointelligenceV1p1beta1_Track]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingBox(
    typing_extensions.TypedDict, total=False
):
    bottom: float
    left: float
    right: float
    top: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudVideointelligenceV1p1beta1_NormalizedVertex]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    entity: GoogleCloudVideointelligenceV1p1beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingFrame]
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment
    trackId: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingConfig(
    typing_extensions.TypedDict, total=False
):
    model: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_PersonDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    tracks: _list[GoogleCloudVideointelligenceV1p1beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_PersonDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    includeAttributes: bool
    includeBoundingBoxes: bool
    includePoseLandmarks: bool

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_ShotChangeDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    model: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_SpeechContext(
    typing_extensions.TypedDict, total=False
):
    phrases: _list[str]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_SpeechRecognitionAlternative(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    transcript: str
    words: _list[GoogleCloudVideointelligenceV1p1beta1_WordInfo]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_SpeechTranscription(
    typing_extensions.TypedDict, total=False
):
    alternatives: _list[
        GoogleCloudVideointelligenceV1p1beta1_SpeechRecognitionAlternative
    ]
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_SpeechTranscriptionConfig(
    typing_extensions.TypedDict, total=False
):
    audioTracks: _list[int]
    diarizationSpeakerCount: int
    enableAutomaticPunctuation: bool
    enableSpeakerDiarization: bool
    enableWordConfidence: bool
    filterProfanity: bool
    languageCode: str
    maxAlternatives: int
    speechContexts: _list[GoogleCloudVideointelligenceV1p1beta1_SpeechContext]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_TextAnnotation(
    typing_extensions.TypedDict, total=False
):
    segments: _list[GoogleCloudVideointelligenceV1p1beta1_TextSegment]
    text: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_TextDetectionConfig(
    typing_extensions.TypedDict, total=False
):
    languageHints: _list[str]
    model: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_TextFrame(
    typing_extensions.TypedDict, total=False
):
    rotatedBoundingBox: GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_TextSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    frames: _list[GoogleCloudVideointelligenceV1p1beta1_TextFrame]
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_TimestampedObject(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p1beta1_DetectedAttribute]
    landmarks: _list[GoogleCloudVideointelligenceV1p1beta1_DetectedLandmark]
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p1beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_Track(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p1beta1_DetectedAttribute]
    confidence: float
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment
    timestampedObjects: _list[GoogleCloudVideointelligenceV1p1beta1_TimestampedObject]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_VideoAnnotationProgress(
    typing_extensions.TypedDict, total=False
):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "LABEL_DETECTION",
        "SHOT_CHANGE_DETECTION",
        "EXPLICIT_CONTENT_DETECTION",
        "FACE_DETECTION",
        "SPEECH_TRANSCRIPTION",
        "TEXT_DETECTION",
        "OBJECT_TRACKING",
        "LOGO_RECOGNITION",
        "PERSON_DETECTION",
    ]
    inputUri: str
    progressPercent: int
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment
    startTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_VideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    error: GoogleRpc_Status
    explicitAnnotation: GoogleCloudVideointelligenceV1p1beta1_ExplicitContentAnnotation
    faceAnnotations: _list[GoogleCloudVideointelligenceV1p1beta1_FaceAnnotation]
    faceDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_FaceDetectionAnnotation
    ]
    frameLabelAnnotations: _list[GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation]
    inputUri: str
    logoRecognitionAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_LogoRecognitionAnnotation
    ]
    objectAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingAnnotation
    ]
    personDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_PersonDetectionAnnotation
    ]
    segment: GoogleCloudVideointelligenceV1p1beta1_VideoSegment
    segmentLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation
    ]
    segmentPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1p1beta1_VideoSegment]
    shotLabelAnnotations: _list[GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation]
    shotPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p1beta1_LabelAnnotation
    ]
    speechTranscriptions: _list[
        GoogleCloudVideointelligenceV1p1beta1_SpeechTranscription
    ]
    textAnnotations: _list[GoogleCloudVideointelligenceV1p1beta1_TextAnnotation]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_VideoContext(
    typing_extensions.TypedDict, total=False
):
    explicitContentDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_ExplicitContentDetectionConfig
    faceDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_FaceDetectionConfig
    labelDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_LabelDetectionConfig
    objectTrackingConfig: GoogleCloudVideointelligenceV1p1beta1_ObjectTrackingConfig
    personDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_PersonDetectionConfig
    segments: _list[GoogleCloudVideointelligenceV1p1beta1_VideoSegment]
    shotChangeDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_ShotChangeDetectionConfig
    speechTranscriptionConfig: GoogleCloudVideointelligenceV1p1beta1_SpeechTranscriptionConfig
    textDetectionConfig: GoogleCloudVideointelligenceV1p1beta1_TextDetectionConfig

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_VideoSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p1beta1_WordInfo(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_AnnotateVideoProgress(
    typing_extensions.TypedDict, total=False
):
    annotationProgress: _list[
        GoogleCloudVideointelligenceV1p2beta1_VideoAnnotationProgress
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_AnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: _list[
        GoogleCloudVideointelligenceV1p2beta1_VideoAnnotationResults
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_DetectedAttribute(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    value: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_DetectedLandmark(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    point: GoogleCloudVideointelligenceV1p2beta1_NormalizedVertex

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_Entity(
    typing_extensions.TypedDict, total=False
):
    description: str
    entityId: str
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_ExplicitContentAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p2beta1_ExplicitContentFrame]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_ExplicitContentFrame(
    typing_extensions.TypedDict, total=False
):
    pornographyLikelihood: typing_extensions.Literal[
        "LIKELIHOOD_UNSPECIFIED",
        "VERY_UNLIKELY",
        "UNLIKELY",
        "POSSIBLE",
        "LIKELY",
        "VERY_LIKELY",
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_FaceAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p2beta1_FaceFrame]
    segments: _list[GoogleCloudVideointelligenceV1p2beta1_FaceSegment]
    thumbnail: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_FaceDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    tracks: _list[GoogleCloudVideointelligenceV1p2beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_FaceFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBoxes: _list[
        GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingBox
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_FaceSegment(
    typing_extensions.TypedDict, total=False
):
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation(
    typing_extensions.TypedDict, total=False
):
    categoryEntities: _list[GoogleCloudVideointelligenceV1p2beta1_Entity]
    entity: GoogleCloudVideointelligenceV1p2beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p2beta1_LabelFrame]
    segments: _list[GoogleCloudVideointelligenceV1p2beta1_LabelSegment]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_LabelFrame(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_LabelSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_LogoRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    entity: GoogleCloudVideointelligenceV1p2beta1_Entity
    segments: _list[GoogleCloudVideointelligenceV1p2beta1_VideoSegment]
    tracks: _list[GoogleCloudVideointelligenceV1p2beta1_Track]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingBox(
    typing_extensions.TypedDict, total=False
):
    bottom: float
    left: float
    right: float
    top: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudVideointelligenceV1p2beta1_NormalizedVertex]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_ObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    entity: GoogleCloudVideointelligenceV1p2beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p2beta1_ObjectTrackingFrame]
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment
    trackId: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_PersonDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    tracks: _list[GoogleCloudVideointelligenceV1p2beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_SpeechRecognitionAlternative(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    transcript: str
    words: _list[GoogleCloudVideointelligenceV1p2beta1_WordInfo]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_SpeechTranscription(
    typing_extensions.TypedDict, total=False
):
    alternatives: _list[
        GoogleCloudVideointelligenceV1p2beta1_SpeechRecognitionAlternative
    ]
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_TextAnnotation(
    typing_extensions.TypedDict, total=False
):
    segments: _list[GoogleCloudVideointelligenceV1p2beta1_TextSegment]
    text: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_TextFrame(
    typing_extensions.TypedDict, total=False
):
    rotatedBoundingBox: GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_TextSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    frames: _list[GoogleCloudVideointelligenceV1p2beta1_TextFrame]
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_TimestampedObject(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p2beta1_DetectedAttribute]
    landmarks: _list[GoogleCloudVideointelligenceV1p2beta1_DetectedLandmark]
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p2beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_Track(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p2beta1_DetectedAttribute]
    confidence: float
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment
    timestampedObjects: _list[GoogleCloudVideointelligenceV1p2beta1_TimestampedObject]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_VideoAnnotationProgress(
    typing_extensions.TypedDict, total=False
):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "LABEL_DETECTION",
        "SHOT_CHANGE_DETECTION",
        "EXPLICIT_CONTENT_DETECTION",
        "FACE_DETECTION",
        "SPEECH_TRANSCRIPTION",
        "TEXT_DETECTION",
        "OBJECT_TRACKING",
        "LOGO_RECOGNITION",
        "PERSON_DETECTION",
    ]
    inputUri: str
    progressPercent: int
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment
    startTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_VideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    error: GoogleRpc_Status
    explicitAnnotation: GoogleCloudVideointelligenceV1p2beta1_ExplicitContentAnnotation
    faceAnnotations: _list[GoogleCloudVideointelligenceV1p2beta1_FaceAnnotation]
    faceDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_FaceDetectionAnnotation
    ]
    frameLabelAnnotations: _list[GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation]
    inputUri: str
    logoRecognitionAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_LogoRecognitionAnnotation
    ]
    objectAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_ObjectTrackingAnnotation
    ]
    personDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_PersonDetectionAnnotation
    ]
    segment: GoogleCloudVideointelligenceV1p2beta1_VideoSegment
    segmentLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation
    ]
    segmentPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1p2beta1_VideoSegment]
    shotLabelAnnotations: _list[GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation]
    shotPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p2beta1_LabelAnnotation
    ]
    speechTranscriptions: _list[
        GoogleCloudVideointelligenceV1p2beta1_SpeechTranscription
    ]
    textAnnotations: _list[GoogleCloudVideointelligenceV1p2beta1_TextAnnotation]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_VideoSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p2beta1_WordInfo(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoProgress(
    typing_extensions.TypedDict, total=False
):
    annotationProgress: _list[
        GoogleCloudVideointelligenceV1p3beta1_VideoAnnotationProgress
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: _list[
        GoogleCloudVideointelligenceV1p3beta1_VideoAnnotationResults
    ]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_Celebrity(
    typing_extensions.TypedDict, total=False
):
    description: str
    displayName: str
    name: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_CelebrityRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    celebrityTracks: _list[GoogleCloudVideointelligenceV1p3beta1_CelebrityTrack]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_CelebrityTrack(
    typing_extensions.TypedDict, total=False
):
    celebrities: _list[GoogleCloudVideointelligenceV1p3beta1_RecognizedCelebrity]
    faceTrack: GoogleCloudVideointelligenceV1p3beta1_Track

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_DetectedAttribute(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    value: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_DetectedLandmark(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    name: str
    point: GoogleCloudVideointelligenceV1p3beta1_NormalizedVertex

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_Entity(
    typing_extensions.TypedDict, total=False
):
    description: str
    entityId: str
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_ExplicitContentAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p3beta1_ExplicitContentFrame]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_ExplicitContentFrame(
    typing_extensions.TypedDict, total=False
):
    pornographyLikelihood: typing_extensions.Literal[
        "LIKELIHOOD_UNSPECIFIED",
        "VERY_UNLIKELY",
        "UNLIKELY",
        "POSSIBLE",
        "LIKELY",
        "VERY_LIKELY",
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_FaceAnnotation(
    typing_extensions.TypedDict, total=False
):
    frames: _list[GoogleCloudVideointelligenceV1p3beta1_FaceFrame]
    segments: _list[GoogleCloudVideointelligenceV1p3beta1_FaceSegment]
    thumbnail: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_FaceDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    thumbnail: str
    tracks: _list[GoogleCloudVideointelligenceV1p3beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_FaceFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBoxes: _list[
        GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingBox
    ]
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_FaceSegment(
    typing_extensions.TypedDict, total=False
):
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation(
    typing_extensions.TypedDict, total=False
):
    categoryEntities: _list[GoogleCloudVideointelligenceV1p3beta1_Entity]
    entity: GoogleCloudVideointelligenceV1p3beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p3beta1_LabelFrame]
    segments: _list[GoogleCloudVideointelligenceV1p3beta1_LabelSegment]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_LabelFrame(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_LabelSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_LogoRecognitionAnnotation(
    typing_extensions.TypedDict, total=False
):
    entity: GoogleCloudVideointelligenceV1p3beta1_Entity
    segments: _list[GoogleCloudVideointelligenceV1p3beta1_VideoSegment]
    tracks: _list[GoogleCloudVideointelligenceV1p3beta1_Track]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingBox(
    typing_extensions.TypedDict, total=False
):
    bottom: float
    left: float
    right: float
    top: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingPoly(
    typing_extensions.TypedDict, total=False
):
    vertices: _list[GoogleCloudVideointelligenceV1p3beta1_NormalizedVertex]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_NormalizedVertex(
    typing_extensions.TypedDict, total=False
):
    x: float
    y: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_ObjectTrackingAnnotation(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    entity: GoogleCloudVideointelligenceV1p3beta1_Entity
    frames: _list[GoogleCloudVideointelligenceV1p3beta1_ObjectTrackingFrame]
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment
    trackId: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_ObjectTrackingFrame(
    typing_extensions.TypedDict, total=False
):
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_PersonDetectionAnnotation(
    typing_extensions.TypedDict, total=False
):
    tracks: _list[GoogleCloudVideointelligenceV1p3beta1_Track]
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_RecognizedCelebrity(
    typing_extensions.TypedDict, total=False
):
    celebrity: GoogleCloudVideointelligenceV1p3beta1_Celebrity
    confidence: float

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_SpeechRecognitionAlternative(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    transcript: str
    words: _list[GoogleCloudVideointelligenceV1p3beta1_WordInfo]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_SpeechTranscription(
    typing_extensions.TypedDict, total=False
):
    alternatives: _list[
        GoogleCloudVideointelligenceV1p3beta1_SpeechRecognitionAlternative
    ]
    languageCode: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_StreamingAnnotateVideoResponse(
    typing_extensions.TypedDict, total=False
):
    annotationResults: GoogleCloudVideointelligenceV1p3beta1_StreamingVideoAnnotationResults
    annotationResultsUri: str
    error: GoogleRpc_Status

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_StreamingVideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    explicitAnnotation: GoogleCloudVideointelligenceV1p3beta1_ExplicitContentAnnotation
    frameTimestamp: str
    labelAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation]
    objectAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_ObjectTrackingAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_VideoSegment]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_TextAnnotation(
    typing_extensions.TypedDict, total=False
):
    segments: _list[GoogleCloudVideointelligenceV1p3beta1_TextSegment]
    text: str
    version: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_TextFrame(
    typing_extensions.TypedDict, total=False
):
    rotatedBoundingBox: GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingPoly
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_TextSegment(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    frames: _list[GoogleCloudVideointelligenceV1p3beta1_TextFrame]
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_TimestampedObject(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p3beta1_DetectedAttribute]
    landmarks: _list[GoogleCloudVideointelligenceV1p3beta1_DetectedLandmark]
    normalizedBoundingBox: GoogleCloudVideointelligenceV1p3beta1_NormalizedBoundingBox
    timeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_Track(
    typing_extensions.TypedDict, total=False
):
    attributes: _list[GoogleCloudVideointelligenceV1p3beta1_DetectedAttribute]
    confidence: float
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment
    timestampedObjects: _list[GoogleCloudVideointelligenceV1p3beta1_TimestampedObject]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_VideoAnnotationProgress(
    typing_extensions.TypedDict, total=False
):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "LABEL_DETECTION",
        "SHOT_CHANGE_DETECTION",
        "EXPLICIT_CONTENT_DETECTION",
        "FACE_DETECTION",
        "SPEECH_TRANSCRIPTION",
        "TEXT_DETECTION",
        "OBJECT_TRACKING",
        "LOGO_RECOGNITION",
        "CELEBRITY_RECOGNITION",
        "PERSON_DETECTION",
    ]
    inputUri: str
    progressPercent: int
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment
    startTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_VideoAnnotationResults(
    typing_extensions.TypedDict, total=False
):
    celebrityRecognitionAnnotations: GoogleCloudVideointelligenceV1p3beta1_CelebrityRecognitionAnnotation
    error: GoogleRpc_Status
    explicitAnnotation: GoogleCloudVideointelligenceV1p3beta1_ExplicitContentAnnotation
    faceAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_FaceAnnotation]
    faceDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_FaceDetectionAnnotation
    ]
    frameLabelAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation]
    inputUri: str
    logoRecognitionAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_LogoRecognitionAnnotation
    ]
    objectAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_ObjectTrackingAnnotation
    ]
    personDetectionAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_PersonDetectionAnnotation
    ]
    segment: GoogleCloudVideointelligenceV1p3beta1_VideoSegment
    segmentLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation
    ]
    segmentPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation
    ]
    shotAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_VideoSegment]
    shotLabelAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation]
    shotPresenceLabelAnnotations: _list[
        GoogleCloudVideointelligenceV1p3beta1_LabelAnnotation
    ]
    speechTranscriptions: _list[
        GoogleCloudVideointelligenceV1p3beta1_SpeechTranscription
    ]
    textAnnotations: _list[GoogleCloudVideointelligenceV1p3beta1_TextAnnotation]

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_VideoSegment(
    typing_extensions.TypedDict, total=False
):
    endTimeOffset: str
    startTimeOffset: str

@typing.type_check_only
class GoogleCloudVideointelligenceV1p3beta1_WordInfo(
    typing_extensions.TypedDict, total=False
):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str

@typing.type_check_only
class GoogleLongrunning_Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpc_Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleRpc_Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AssuredworkloadsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleLongrunningListOperationsResponseHttpRequest,
                    previous_response: GoogleLongrunningListOperationsResponse,
                ) -> GoogleLongrunningListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class WorkloadsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class OrganizationsResource(googleapiclient.discovery.Resource):
                    @typing.type_check_only
                    class LocationsResource(googleapiclient.discovery.Resource):
                        @typing.type_check_only
                        class WorkloadsResource(googleapiclient.discovery.Resource):
                            def analyzeWorkloadMove(
                                self,
                                *,
                                source: str,
                                target: str,
                                project: str = ...,
                                **kwargs: typing.Any
                            ) -> GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponseHttpRequest: ...

                        def workloads(self) -> WorkloadsResource: ...

                    def locations(self) -> LocationsResource: ...

                @typing.type_check_only
                class ViolationsResource(googleapiclient.discovery.Resource):
                    def acknowledge(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponseHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudAssuredworkloadsV1beta1ViolationHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        filter: str = ...,
                        interval_endTime: str = ...,
                        interval_startTime: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudAssuredworkloadsV1beta1ListViolationsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: GoogleCloudAssuredworkloadsV1beta1ListViolationsResponseHttpRequest,
                        previous_response: GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse,
                    ) -> GoogleCloudAssuredworkloadsV1beta1ListViolationsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudAssuredworkloadsV1beta1Workload = ...,
                    externalId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self, *, name: str, etag: str = ..., **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudAssuredworkloadsV1beta1WorkloadHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponseHttpRequest,
                    previous_response: GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse,
                ) -> GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudAssuredworkloadsV1beta1Workload = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudAssuredworkloadsV1beta1WorkloadHttpRequest: ...
                def restrictAllowedResources(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponseHttpRequest: ...
                def organizations(self) -> OrganizationsResource: ...
                def violations(self) -> ViolationsResource: ...

            def operations(self) -> OperationsResource: ...
            def workloads(self) -> WorkloadsResource: ...

        def locations(self) -> LocationsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class OrganizationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class LocationsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class WorkloadsResource(googleapiclient.discovery.Resource):
                    def analyzeWorkloadMove(
                        self,
                        *,
                        project: str,
                        target: str,
                        source: str = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponseHttpRequest: ...

                def workloads(self) -> WorkloadsResource: ...

            def locations(self) -> LocationsResource: ...

        def organizations(self) -> OrganizationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1AcknowledgeViolationResponse: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1AnalyzeWorkloadMoveResponse: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1ListViolationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1ListViolationsResponse: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1ListWorkloadsResponse: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1RestrictAllowedResourcesResponse: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1ViolationHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1Violation: ...

@typing.type_check_only
class GoogleCloudAssuredworkloadsV1beta1WorkloadHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudAssuredworkloadsV1beta1Workload: ...

@typing.type_check_only
class GoogleLongrunningListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...
